@@ -34,6 +34,7 @@ from .. import log
 from .. import util
 from ..util.typing import Literal
 from ..util.typing import Protocol
+from ..util.typing import Self
 
 if TYPE_CHECKING:
     from ..engine.interfaces import DBAPIConnection
@@ -1124,6 +1125,13 @@ class PoolProxiedConnection(ManagesConnection):
         """
         raise NotImplementedError()
 
+    def __enter__(self) -> Self:
+        return self
+
+    def __exit__(self, exc_type: Any, exc_value: Any, traceback: Any) -> None:
+        self.close()
+        return None
+
 
 class _AdhocProxiedConnection(PoolProxiedConnection):
     """provides the :class:`.PoolProxiedConnection` interface for cases where
